Module backend

Module backend 

Property selector enums and jmap_types::JmapObject impls for RFC 8621 types.

These are defined here so that jmap-mail-server can use them without violating the orphan rule (JmapObject is foreign but the mail types are local to this crate).

Enums

EmailProperty
Property selector for crate::Email /get and /set.
EmailSubmissionProperty
Property selector for crate::EmailSubmission /get and /set.
IdentityProperty
Property selector for crate::Identity /get and /set.
MailboxProperty
Property selector for crate::Mailbox /get and /set.
SearchSnippetProperty
Property selector for crate::SearchSnippet /get.
ThreadProperty
Property selector for crate::Thread /get.
VacationResponseProperty
Property selector for crate::VacationResponse /get and /set.