Identity

Struct Identity 

#[non_exhaustive]
pub struct Identity { pub id: Id, pub name: String, pub email: String, pub reply_to: Option<Vec<EmailAddress>>, pub bcc: Option<Vec<EmailAddress>>, pub text_signature: String, pub html_signature: String, pub may_delete: bool, }
An RFC 8621 6 Identity object.

Stores information about an email address or domain the user may send from.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Id

The id of the Identity (immutable; server-set).

name: String

The “From” name the client SHOULD use when creating a new Email from this Identity. Defaults to "".

email: String

The “From” email address the client MUST use (immutable).

reply_to: Option<Vec<EmailAddress>>

The Reply-To value the client SHOULD set. null if not set.

bcc: Option<Vec<EmailAddress>>

The Bcc value the client SHOULD set. null if not set.

text_signature: String

Plaintext signature. Defaults to "".

html_signature: String

HTML snippet signature. Defaults to "".

may_delete: bool

Whether the user may delete this Identity (server-set).

Implementations

Source

impl Identity

pub fn new(id: Id, email: impl Into<String>, may_delete: bool) -> Self

Construct an Identity from its three identifying fields.

name, text_signature, and html_signature default to "". reply_to and bcc default to None.