#[non_exhaustive]pub enum ComparatorProperty {
ReceivedAt,
Size,
From,
To,
Subject,
SentAt,
HasKeyword,
AllInThreadHaveKeyword,
SomeInThreadHaveKeyword,
Other(String),
}Expand description
The property to sort by in an EmailComparator (RFC 8621 4.4.2).
When the variant is HasKeyword,
AllInThreadHaveKeyword, or
SomeInThreadHaveKeyword,
the keyword field on EmailComparator MUST also be set
(RFC 8621 4.4.2).
Unknown property names from the server are preserved in
Other so they round-trip correctly.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReceivedAt
Sort by receivedAt.
Size
Sort by message size in octets.
From
Sort by the text of the From header field.
To
Sort by the text of the To header field.
Subject
Sort by the decoded Subject.
SentAt
Sort by sentAt.
HasKeyword
Sort by whether Emails in the Thread have the given keyword.
AllInThreadHaveKeyword
Sort by whether all Emails in the Thread have the given keyword.
SomeInThreadHaveKeyword
Sort by whether some Emails in the Thread have the given keyword.
Other(String)
A server-extension property name not listed above.